==> opensaml-soap-impl-3.0.0-sources.jar: org/opensaml/soap/wssecurity/impl/TransformationParametersBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development, 
 * Inc. (UCAID) under one or more contributor license agreements.  See the 
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache 
 * License, Version 2.0 (the "License"); you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wssecurity.impl;

import org.opensaml.soap.wssecurity.TransformationParameters;

/**
 * TransformationParametersBuilder.
 */
public class TransformationParametersBuilder extends AbstractWSSecurityObjectBuilder<TransformationParameters> {

    /** {@inheritDoc} */
    public TransformationParameters buildObject() {
        return buildObject(TransformationParameters.ELEMENT_NAME);
    }

    /** {@inheritDoc} */
    public TransformationParameters buildObject(String namespaceURI, String localName, String namespacePrefix) {
        return new TransformationParametersImpl(namespaceURI, localName, namespacePrefix);
    }

}

==> opensaml-soap-impl-4.0.1-sources.jar: org/opensaml/soap/wssecurity/impl/TransformationParametersBuilder.java <==
/*
 * Licensed to the University Corporation for Advanced Internet Development,
 * Inc. (UCAID) under one or more contributor license agreements.  See the
 * NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The UCAID licenses this file to You under the Apache
 * License, Version 2.0 (the "License"); you may not use this file except in
 * compliance with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opensaml.soap.wssecurity.impl;

import org.opensaml.soap.wssecurity.TransformationParameters;

/**
 * TransformationParametersBuilder.
 */
public class TransformationParametersBuilder extends AbstractWSSecurityObjectBuilder<TransformationParameters> {

    /** {@inheritDoc} */
    public TransformationParameters buildObject() {
        return buildObject(TransformationParameters.ELEMENT_NAME);
    }

    /** {@inheritDoc} */
    public TransformationParameters buildObject(final String namespaceURI, final String localName,
            final String namespacePrefix) {
        return new TransformationParametersImpl(namespaceURI, localName, namespacePrefix);
    }

}
